@@ -82,10 +82,10 @@ DebugSession::DebugSession()
 
     m_procLineMaker = new KDevelop::ProcessLineMaker(this);
 
-    connect( m_procLineMaker, SIGNAL(receivedStdoutLines(const QStringList&)),
-             this, SIGNAL(applicationStandardOutputLines(const QStringList&)));
-    connect( m_procLineMaker, SIGNAL(receivedStderrLines(const QStringList&)),
-             this, SIGNAL(applicationStandardErrorLines(const QStringList&)) );
+    connect( m_procLineMaker, SIGNAL(receivedStdoutLines(QStringList)),
+             this, SIGNAL(applicationStandardOutputLines(QStringList)));
+    connect( m_procLineMaker, SIGNAL(receivedStderrLines(QStringList)),
+             this, SIGNAL(applicationStandardErrorLines(QStringList)) );
     setupController();
 }
 
@@ -129,21 +129,21 @@ KDevelop::IFrameStackModel* DebugSession::createFrameStackModel()
 void DebugSession::setupController()
 {
     // variableTree -> gdbBreakpointWidget
-//     connect( variableTree,          SIGNAL(toggleWatchpoint(const QString &)),
-//              gdbBreakpointWidget,   SLOT(slotToggleWatchpoint(const QString &)));
+//     connect( variableTree,          SIGNAL(toggleWatchpoint(QString)),
+//              gdbBreakpointWidget,   SLOT(slotToggleWatchpoint(QString)));
 
     // controller -> procLineMaker
-    connect( this,            SIGNAL(ttyStdout(const QByteArray&)),
-             m_procLineMaker,         SLOT(slotReceivedStdout(const QByteArray&)));
-    connect( this,            SIGNAL(ttyStderr(const QByteArray&)),
-             m_procLineMaker,         SLOT(slotReceivedStderr(const QByteArray&)));
+    connect( this,            SIGNAL(ttyStdout(QByteArray)),
+             m_procLineMaker,         SLOT(slotReceivedStdout(QByteArray)));
+    connect( this,            SIGNAL(ttyStderr(QByteArray)),
+             m_procLineMaker,         SLOT(slotReceivedStderr(QByteArray)));
 
 //     connect(statusBarIndicator, SIGNAL(doubleClicked()),
 //             controller, SLOT(explainDebuggerStatus()));
 
     // TODO: reimplement / re-enable
-    //connect(this, SIGNAL(addWatchVariable(const QString&)), controller->variables(), SLOT(slotAddWatchVariable(const QString&)));
-    //connect(this, SIGNAL(evaluateExpression(const QString&)), controller->variables(), SLOT(slotEvaluateExpression(const QString&)));
+    //connect(this, SIGNAL(addWatchVariable(QString)), controller->variables(), SLOT(slotAddWatchVariable(QString)));
+    //connect(this, SIGNAL(evaluateExpression(QString)), controller->variables(), SLOT(slotEvaluateExpression(QString)));
 }
 
 void DebugSession::_gdbStateChanged(DBGStateFlags oldState, DBGStateFlags newState)
@@ -324,10 +324,10 @@ void DebugSession::stopDebugger()
 
     // Get gdb's attention if it's busy. We need gdb to be at the
     // command line so we can stop it.
-    if (!m_gdb->isReady())
+    if (!m_gdb.data()->isReady())
     {
         kDebug(9012) << "gdb busy on shutdown - interruping";
-        m_gdb->interrupt();
+        m_gdb.data()->interrupt();
     }
 
     // If the app is attached then we release it here. This doesn't stop
@@ -357,7 +357,7 @@ void DebugSession::interruptDebugger()
 
     setStateOn(s_explicitBreakInto);
 
-    m_gdb->interrupt();
+    m_gdb.data()->interrupt();
 }
 
 void DebugSession::runToCursor()
@@ -590,7 +590,7 @@ bool DebugSession::executeCmd()
 {
     Q_ASSERT(m_gdb);
 
-    if (!m_gdb->isReady())
+    if (!m_gdb.data()->isReady())
         return false;
 
     GDBCommand* currentCmd = commandQueue_->nextCommand();
@@ -637,7 +637,7 @@ bool DebugSession::executeCmd()
         return executeCmd();
     }
 
-    m_gdb->execute(currentCmd);
+    m_gdb.data()->execute(currentCmd);
     return true;
 }
 
@@ -660,7 +660,11 @@ void DebugSession::slotProgramStopped(const GDBMI::ResultRecord& r)
 
     if (reason == "exited-normally" || reason == "exited")
     {
-        programNoApp(i18n("Exited normally"));
+        if (r.hasField("exit-code")) {
+            programNoApp(i18n("Exited with return code: %1").arg(r["exit-code"].literal()));
+        } else {
+            programNoApp(i18n("Exited normally"));
+        }
         programHasExited_ = true;
         state_reload_needed = false;
         return;
@@ -796,8 +800,8 @@ void DebugSession::programNoApp(const QString& msg)
     delete tty_;
     tty_ = 0;
 
-    m_gdb->kill();
-    m_gdb->deleteLater();
+    m_gdb.data()->kill();
+    m_gdb.data()->deleteLater();
 
     setStateOn(s_dbgNotStarted);
 
@@ -845,11 +849,12 @@ bool DebugSession::startDebugger(KDevelop::ILaunchConfiguration* cfg)
 
     if(m_gdb) {
         kWarning() << "m_gdb object still existed";
-        delete m_gdb;
-        m_gdb = 0;
+        delete m_gdb.data();
+        m_gdb.clear();
     }
 
-    m_gdb = new GDB(this);
+    GDB* gdb = new GDB(this);
+    m_gdb = gdb;
 
     // FIXME: here, we should wait until GDB is up and waiting for input.
     // Then, clear s_dbgNotStarted
@@ -859,25 +864,25 @@ bool DebugSession::startDebugger(KDevelop::ILaunchConfiguration* cfg)
     /** FIXME: connect ttyStdout. It takes QByteArray, so
         I'm not sure what to do.  */
 #if 0
-    connect(m_gdb, SIGNAL(applicationOutput(const QString&)),
-            this, SIGNAL(ttyStdout(const QString &)));
+    connect(gdb, SIGNAL(applicationOutput(QString)),
+            this, SIGNAL(ttyStdout(QString)));
 #endif
-    connect(m_gdb, SIGNAL(userCommandOutput(const QString&)), this,
-            SIGNAL(gdbUserCommandStdout(const QString&)));
-    connect(m_gdb, SIGNAL(internalCommandOutput(const QString&)), this,
-            SIGNAL(gdbInternalCommandStdout(const QString&)));
+    connect(gdb, SIGNAL(userCommandOutput(QString)), this,
+            SIGNAL(gdbUserCommandStdout(QString)));
+    connect(gdb, SIGNAL(internalCommandOutput(QString)), this,
+            SIGNAL(gdbInternalCommandStdout(QString)));
 
-    connect(m_gdb, SIGNAL(ready()), this, SLOT(gdbReady()));
-    connect(m_gdb, SIGNAL(gdbExited()), this, SLOT(gdbExited()));
-    connect(m_gdb, SIGNAL(programStopped(const GDBMI::ResultRecord&)),
-            this, SLOT(slotProgramStopped(const GDBMI::ResultRecord&)));
-    connect(m_gdb, SIGNAL(programStopped(const GDBMI::ResultRecord&)),
-            this, SIGNAL(programStopped(const GDBMI::ResultRecord&)));
-    connect(m_gdb, SIGNAL(programRunning()),
+    connect(gdb, SIGNAL(ready()), this, SLOT(gdbReady()));
+    connect(gdb, SIGNAL(gdbExited()), this, SLOT(gdbExited()));
+    connect(gdb, SIGNAL(programStopped(GDBMI::ResultRecord)),
+            this, SLOT(slotProgramStopped(GDBMI::ResultRecord)));
+    connect(gdb, SIGNAL(programStopped(GDBMI::ResultRecord)),
+            this, SIGNAL(programStopped(GDBMI::ResultRecord)));
+    connect(gdb, SIGNAL(programRunning()),
             this, SLOT(programRunning()));
 
-    connect(m_gdb, SIGNAL(streamRecord(const GDBMI::StreamRecord&)),
-            this, SLOT(parseStreamRecord(const GDBMI::StreamRecord&)));
+    connect(gdb, SIGNAL(streamRecord(GDBMI::StreamRecord)),
+            this, SLOT(parseStreamRecord(GDBMI::StreamRecord)));
 
     // Start gdb. Do this after connecting all signals so that initial
     // GDB output, and important events like "GDB died" are reported.
@@ -886,14 +891,14 @@ bool DebugSession::startDebugger(KDevelop::ILaunchConfiguration* cfg)
     if (cfg)
     {
         KConfigGroup config = cfg->config();
-        m_gdb->start(config);
+        m_gdb.data()->start(config);
     }
     else
     {
         // FIXME: this is hack, I am not sure there's any way presently
         // to edit this via GUI.
         KConfigGroup config(KGlobal::config(), "GDB Debugger");
-        m_gdb->start(config);
+        m_gdb.data()->start(config);
     }
 
     setStateOff(s_dbgNotStarted);
@@ -989,8 +994,8 @@ bool DebugSession::startProgram(KDevelop::ILaunchConfiguration* cfg)
     tty_ = new STTY(config_useExternalTerminal, config_externalTerminal);
     if (!config_useExternalTerminal)
     {
-        connect( tty_, SIGNAL(OutOutput(const QByteArray&)), SIGNAL(ttyStdout(const QByteArray&)) );
-        connect( tty_, SIGNAL(ErrOutput(const QByteArray&)), SIGNAL(ttyStderr(const QByteArray&)) );
+        connect( tty_, SIGNAL(OutOutput(QByteArray)), SIGNAL(ttyStdout(QByteArray)) );
+        connect( tty_, SIGNAL(ErrOutput(QByteArray)), SIGNAL(ttyStderr(QByteArray)) );
     }
 
     QString tty(tty_->getSlave());
@@ -1022,7 +1027,7 @@ bool DebugSession::startProgram(KDevelop::ILaunchConfiguration* cfg)
         dir = QFileInfo(executable).absolutePath();
     }
     
-    queueCmd(new GDBCommand(GDBMI::EnvironmentCd, dir));
+    queueCmd(new GDBCommand(GDBMI::EnvironmentCd, KShell::quoteArg(dir)));
 
     // Set the run arguments
     if (!arguments.isEmpty())
@@ -1048,7 +1053,7 @@ bool DebugSession::startProgram(KDevelop::ILaunchConfiguration* cfg)
         queueCmd(new GDBCommand(GDBMI::GdbSet, "print asm-demangle off"));
 
     if (config_configGdbScript_.isValid())
-        queueCmd(new GDBCommand(GDBMI::NonMI, "source " + config_configGdbScript_.toLocalFile()));
+        queueCmd(new GDBCommand(GDBMI::NonMI, "source " + KShell::quoteArg(config_configGdbScript_.toLocalFile())));
 
 
     if (!config_runShellScript_.isEmpty()) {
@@ -1058,9 +1063,10 @@ bool DebugSession::startProgram(KDevelop::ILaunchConfiguration* cfg)
 
         QProcess *proc = new QProcess;
         QStringList arguments;
-        arguments << "-c" << config_runShellScript_.toLocalFile() +
-            ' ' + executable + QString::fromAscii( options );
+        arguments << "-c" << KShell::quoteArg(config_runShellScript_.toLocalFile()) +
+            ' ' + KShell::quoteArg(executable) + QString::fromAscii( options );
 
+        kDebug() << "starting sh" << arguments;
         proc->start("sh", arguments);
         //PORTING TODO QProcess::DontCare);
     }
@@ -1073,14 +1079,16 @@ bool DebugSession::startProgram(KDevelop::ILaunchConfiguration* cfg)
         // Future: the shell script should be able to pass info (like pid)
         // to the gdb script...
 
-        kDebug(9012) << "Running gdb script " << config_runGdbScript_.toLocalFile();
-        queueCmd(new GDBCommand(GDBMI::NonMI, "source " + config_runGdbScript_.toLocalFile()));
+        kDebug(9012) << "Running gdb script " << KShell::quoteArg(config_runGdbScript_.toLocalFile());
+        queueCmd(new GDBCommand(GDBMI::NonMI, "source " + KShell::quoteArg(config_runGdbScript_.toLocalFile())));
 
         // Note: script could contain "run" or "continue"
+
+        raiseEvent(connected_to_program);
     }
     else
     {
-        queueCmd(new GDBCommand(GDBMI::FileExecAndSymbols, executable, this, &DebugSession::handleFileExecAndSymbols, true));
+        queueCmd(new GDBCommand(GDBMI::FileExecAndSymbols, KShell::quoteArg(executable), this, &DebugSession::handleFileExecAndSymbols, true));
         raiseEvent(connected_to_program);
         queueCmd(new GDBCommand(GDBMI::ExecRun));
     }
@@ -1104,7 +1112,7 @@ void DebugSession::slotKillGdb()
     if (!stateIsOn(s_programExited) && stateIsOn(s_shuttingDown))
     {
         kDebug(9012) << "gdb not shutdown - killing";
-        m_gdb->kill();
+        m_gdb.data()->kill();
 
         setState(s_dbgNotStarted | s_appNotStarted);
 
@@ -1191,7 +1199,7 @@ void DebugSession::defaultErrorHandler(const GDBMI::ResultRecord& result)
     //
     // Also, don't reload state on errors appeared during state
     // reloading!
-    if (!m_gdb->currentCommand()->stateReloading())
+    if (!m_gdb.data()->currentCommand()->stateReloading())
         raiseEvent(program_state_changed);
 }
 
@@ -1274,7 +1282,7 @@ void DebugSession::slotUserGDBCmd(const QString& cmd)
 
 void DebugSession::explainDebuggerStatus()
 {
-    GDBCommand* currentCmd_ = m_gdb->currentCommand();
+    GDBCommand* currentCmd_ = m_gdb.data()->currentCommand();
     QString information =
         i18np("1 command in queue\n", "%1 commands in queue\n", commandQueue_->count()) +
         i18ncp("Only the 0 and 1 cases need to be translated", "1 command being processed by gdb\n", "%1 commands being processed by gdb\n", (currentCmd_ ? 1 : 0)) +
