@@ -44,7 +44,7 @@
 #include <ktexteditor/codecompletioninterface.h>
 #include <ktexteditor/movingrange.h>
 #include <ktexteditor/movinginterface.h>
-
+#include <memory>
 using namespace KDevelop;
 
 namespace Cpp {
@@ -79,9 +79,9 @@ void NormalDeclarationCompletionItem::execute(KTextEditor::Document* document, c
       functionSignature += '(' + classFun->normalizedSignature().str() + ')';
       if(addSignalSlot) {
         if(classFun->isSignal())
-          functionSignature = "SIGNAL(" + functionSignature + ')';
+          functionSignature = "SIGNAL("+functionSignature+')';
         else
-          functionSignature = "SLOT(" + functionSignature + ')';
+          functionSignature = "SLOT("+functionSignature+')';
       }else{
         //Only add a closing )
         functionSignature += ')';
@@ -180,9 +180,19 @@ void NormalDeclarationCompletionItem::execute(KTextEditor::Document* document, c
       }
       insertFunctionParenText(document, insertionPosition, m_declaration, jumpForbidden);
     }
+    
+    if (removeInSecondStep.get()) {
+      //if we would remove text after the inserted text, skip that if it is a property
+      //of the executed item and additionally insert a . or ->
+      Identifier id(document->text(removeInSecondStep->toRange()));
+      QString insertAccessor = keepRemainingWord(id);
+      if (!insertAccessor.isEmpty()) {
+        document->insertText(removeInSecondStep->toRange().start(), insertAccessor);
+        removeInSecondStep.release();
+      }
+    }
   }
   
-  
   if(removeInSecondStep.get())
   {
     KTextEditor::Range removeRange = removeInSecondStep->toRange();
@@ -199,6 +209,65 @@ void NormalDeclarationCompletionItem::execute(KTextEditor::Document* document, c
   }
 }
 
+QString NormalDeclarationCompletionItem::keepRemainingWord(Identifier id)
+{
+  DUChainReadLocker lock;
+
+  if (!m_declaration) {
+    return QString();
+  }
+
+  TypePtr<StructureType> type;
+  QString insertAccessor;
+  if (m_declaration->type<StructureType>()) {
+    type = m_declaration->type<StructureType>();
+    if (m_declaration->internalContext() && m_declaration->internalContext()->type() == DUContext::Class) {
+      insertAccessor = "::";
+    } else {
+      insertAccessor = ".";
+    }
+  } else if (m_declaration->type<PointerType>()) {
+    type = StructureType::Ptr::dynamicCast(m_declaration->type<PointerType>()->baseType());
+    insertAccessor = "->";
+  }
+  if (!type && (m_declaration->type<ReferenceType>())) {
+    type = StructureType::Ptr::dynamicCast(m_declaration->type<ReferenceType>()->baseType());
+    insertAccessor = ".";
+  }
+  if (type) {
+    return keepRemainingWord(type, id, insertAccessor);
+  }
+  return QString();
+}
+
+QString NormalDeclarationCompletionItem::keepRemainingWord(const StructureType::Ptr &type, const Identifier &id, const QString &insertAccessor)
+{
+  ENSURE_CHAIN_READ_LOCKED;
+  Q_ASSERT(m_declaration);
+
+  if (Declaration* structDecl = type->declaration(m_declaration->topContext())) {
+    if (!structDecl->internalContext()) {
+      return QString();
+    }
+    if (structDecl->internalContext()->findDeclarations(id).count()) {
+      return insertAccessor;
+    }
+    // might be a smart pointer or similar, hence check retval of operator-> if available
+    const QList<Declaration*> opDecs = structDecl->internalContext()->findDeclarations(Identifier( "operator->" ));
+    if (!opDecs.isEmpty()) {
+      Declaration* smartPtrFn = opDecs.first();
+      if (FunctionType::Ptr funType = smartPtrFn->type<FunctionType>()) {
+        if (PointerType::Ptr ptrRetType = PointerType::Ptr::dynamicCast(funType->returnType())) {
+          if (StructureType::Ptr retStructType = StructureType::Ptr::dynamicCast(ptrRetType->baseType())) {
+            return keepRemainingWord(retStructType, id, "->");
+          }
+        }
+      }
+    }
+  }
+  return QString();
+}
+
 const bool indentByDepth = false;
 
 //The name to be viewed in the name column
@@ -321,7 +390,7 @@ KDevelop::QualifiedIdentifier NormalDeclarationCompletionItem::stripPrefix() con
 
 QList<KDevelop::IndexedType> NormalDeclarationCompletionItem::typeForArgumentMatching() const {
   QList<KDevelop::IndexedType> ret;
-  if( m_declaration && completionContext() && completionContext()->memberAccessOperation() == Cpp::CodeCompletionContext::FunctionCallAccess )
+  if( m_declaration && completionContext() && completionContext()->accessType() == Cpp::CodeCompletionContext::FunctionCallAccess )
   {
     if(listOffset < completionContext()->functions().count()) {
       Cpp::CodeCompletionContext::Function f( completionContext()->functions()[listOffset] );
@@ -428,13 +497,13 @@ QVariant NormalDeclarationCompletionItem::data(const QModelIndex& index, int rol
             indentation = QString(depth, ' ');
 
           if(m_declaration->kind() == Declaration::Namespace)
-            return indentation + "namespace";
+            return QString(indentation + "namespace");
           
           if( NamespaceAliasDeclaration* alias = dynamic_cast<NamespaceAliasDeclaration*>(dec) ) {
             if( alias->identifier().isEmpty() ) {
-              return indentation + "using namespace";/* " + alias->importIdentifier().toString();*/
+              return QString(indentation + "using namespace");/* " + alias->importIdentifier().toString();*/
             } else {
-              return indentation + "namespace";/* " + alias->identifier().toString() + " = " + alias->importIdentifier().toString();*/
+              return QString(indentation + "namespace");/* " + alias->identifier().toString() + " = " + alias->importIdentifier().toString();*/
             }
           }
 
@@ -447,19 +516,19 @@ QVariant NormalDeclarationCompletionItem::data(const QModelIndex& index, int rol
                 if(classDecl) {
                   switch (classDecl->classType()) {
                     case ClassDeclarationData::Class:
-                      return indentation + "class";
+                      return QString(indentation + "class");
                       break;
                     case ClassDeclarationData::Struct:
-                      return indentation + "struct";
+                      return QString(indentation + "struct");
                       break;
                     case ClassDeclarationData::Union:
-                      return indentation + "union";
+                      return QString(indentation + "union");
                       break;
                     default:
                       ;
                   }
                 }else if(dec->isForwardDeclaration()) {
-                  return indentation + "class"; ///@todo Would be useful to have the class/struct/union info also for forward-declarations
+                  return QString(indentation + "class"); ///@todo Would be useful to have the class/struct/union info also for forward-declarations
                 }
               }
               if(dec->type<EnumerationType>()) {
@@ -753,7 +822,7 @@ uint MoreArgumentHintsCompletionItem::resetMaxArgumentHints(bool isAutomaticComp
   return ret;
 }
 
-void MoreArgumentHintsCompletionItem::execute(KTextEditor::Document* document, const KTextEditor::Range& word)
+void MoreArgumentHintsCompletionItem::execute(KTextEditor::Document* document, const KTextEditor::Range& /*word*/)
 {
   currentMaxArgumentHints = m_oldNumber + maxArgumentHintsExtensionSteps;
   
