@@ -192,7 +192,7 @@ KDevelop::DocumentChangeSet CppNewClass::generate()
       KDialog d;
       QWidget *w=new QWidget(&d);
       w->setLayout(new QVBoxLayout);
-      w->layout()->addWidget(new QLabel("Choose one target to add the file or cancel if you do not want to do so."));
+      w->layout()->addWidget(new QLabel(i18n("Choose one target to add the file or cancel if you do not want to do so.")));
       QListWidget* targetsWidget=new QListWidget(w);
       targetsWidget->setSelectionMode(QAbstractItemView::SingleSelection);
       foreach(ProjectTargetItem* it, t) {
@@ -218,16 +218,13 @@ KDevelop::DocumentChangeSet CppNewClass::generate()
   {
     ProjectFileItem* file = p->projectFileManager()->addFile(implementationUrl(), folder);
     ProjectFileItem* header = p->projectFileManager()->addFile(headerUrl(), folder);
+    QList<ProjectFileItem*> itemsToAdd;
+    if (file)
+      itemsToAdd << file;
+    if (header)
+      itemsToAdd << header;
 
-    if(file)
-      p->buildSystemManager()->addFileToTarget(file, target);
-    else
-      kWarning() << "Could not add source file to build manager" << implementationUrl();
-    
-    if(header)
-      p->buildSystemManager()->addFileToTarget(header, target);
-    else
-      kWarning() << "Could not add header file to build-manager" << headerUrl();
+    p->buildSystemManager()->addFilesToTarget(itemsToAdd, target);
   }
 
   return changes;
