@@ -247,13 +247,6 @@ private:
    */
   AbstractType::Ptr realLastType(bool* constant = 0) const;
 
-  /**
-   * Returns true when m_lastType either is a pointer, or a reference to a pointer
-   *
-   *  !!DU-Chain must be locked!
-   **/
-  bool isPointerType() const;
-
   /**
    * Dereferences m_lastType if it is a pointer-type, else returns false.
    *
@@ -347,6 +340,7 @@ private:
   virtual void visitUnaryExpression(UnaryExpressionAST *) ;
   virtual void visitSignalSlotExpression (SignalSlotExpressionAST*);
   virtual void visitTypeIDOperator(TypeIDOperatorAST *);
+  virtual void visitLambdaExpression(LambdaExpressionAST *);
   virtual void visit(AST* node);
 
   void putStringType();
