@@ -37,8 +37,8 @@
 using namespace KDevelop;
 using namespace Cpp;
 
-NameASTVisitor::NameASTVisitor(ParseSession* session, Cpp::ExpressionVisitor* visitor, const KDevelop::DUContext* context, const KDevelop::TopDUContext* source, const KDevelop::DUContext* localVisibilityContext, const SimpleCursor& position, KDevelop::DUContext::SearchFlags localSearchFlags, bool debug )
-: m_session(session), m_visitor(visitor), m_context(context), m_source(source), m_localContext(localVisibilityContext), m_find(m_context, m_source, localSearchFlags, SimpleCursor(position) ), m_debug(debug), m_finalName(0)
+NameASTVisitor::NameASTVisitor(ParseSession* session, Cpp::ExpressionVisitor* visitor, const KDevelop::DUContext* context, const KDevelop::TopDUContext* source, const KDevelop::DUContext* localVisibilityContext, const CursorInRevision& position, KDevelop::DUContext::SearchFlags localSearchFlags, bool debug )
+: m_session(session), m_visitor(visitor), m_context(context), m_source(source), m_localContext(localVisibilityContext), m_find(m_context, m_source, localSearchFlags, CursorInRevision(position) ), m_debug(debug), m_finalName(0)
 {
   m_flags = localSearchFlags;
   m_stopSearch = false;
@@ -69,54 +69,59 @@ void NameASTVisitor::visitUnqualifiedName(UnqualifiedNameAST *node)
 
   if (node->id)
     tmp_name = m_session->token_stream->token(node->id).symbol();
-
   if (node->tilde)
     tmp_name = IndexedString(QLatin1String("~") + tmp_name.str());
-
-  if (OperatorFunctionIdAST *op_id = node->operator_id)
-    {
+  if (OperatorFunctionIdAST *op_id = node->operator_id) {
 #if defined(__GNUC__)
 #warning "NameASTVisitor::visitUnqualifiedName() -- implement me"
 #endif
 
-      QString tmpString;
-      tmpString += QLatin1String("operator");
+    QString tmpString;
+    tmpString += QLatin1String("operator");
 
-      if (op_id->op && op_id->op->op)
-        tmpString +=  decode(m_session, op_id->op, true);
-      else
-        tmpString += QLatin1String("{...cast...}");
+    if (op_id->op && op_id->op->op)
+      tmpString +=  decode(m_session, op_id->op, true);
+    else
+      tmpString += QLatin1String("{...cast...}");
 
-      tmp_name = IndexedString(tmpString);
-
-      m_typeSpecifier = op_id->type_specifier;
-    }
+    tmp_name = IndexedString(tmpString);
 
+    m_typeSpecifier = op_id->type_specifier;
+  }
   m_currentIdentifier = Identifier(tmp_name);
   m_find.openIdentifier(m_currentIdentifier);
 
-  if (node->template_arguments)
-    {
-      visitNodes(this, node->template_arguments);
-    }else if(node->end_token == node->start_token + 3 && node->id == node->start_token && m_session->token_stream->token(node->id+1).symbol() == KDevelop::IndexedString('<')) {
-      ///@todo Represent this nicer in the AST
-      ///It's probably a type-specifier with instantiation of the default-parameter, like "Bla<>".
-      m_find.openQualifiedIdentifier( ExpressionEvaluationResult() );
-      m_find.closeQualifiedIdentifier();
-    }
+  if (node->template_arguments) {
+    visitNodes(this, node->template_arguments);
+  } else if(node->end_token == node->start_token + 3 && node->id == node->start_token
+            && m_session->token_stream->token(node->id+1).symbol() == KDevelop::IndexedString('<'))
+  {
+    ///@todo Represent this nicer in the AST
+    ///It's probably a type-specifier with instantiation of the default-parameter, like "Bla<>".
+    m_find.openQualifiedIdentifier( ExpressionEvaluationResult() );
+    m_find.closeQualifiedIdentifier();
+  }
 
   {
     LOCKDUCHAIN;
     m_find.closeIdentifier(node == m_finalName);
   }
-
-  if( node->id && !m_find.lastDeclarations().isEmpty() ) {
+  if( (node->id || node->operator_id) && !m_find.lastDeclarations().isEmpty() ) {
     bool had = false;
+    uint start_token;
+    uint end_token;
+    if ( node->id ) {
+      start_token = node->id;
+      end_token = node->id + 1;
+    } else {
+      start_token = node->start_token;
+      end_token = node->end_token;
+    }
     foreach(const DeclarationPointer &decl, m_find.lastDeclarations()) {
       if(decl && !decl->isForwardDeclaration()) {
         //Prefer registering non forward-declaration uses
         if(m_visitor)
-          m_visitor->newUse( node, node->id, node->id+1, decl );
+          m_visitor->newUse( node, start_token, end_token, decl );
         had = true;
         break;
       }
@@ -124,7 +129,7 @@ void NameASTVisitor::visitUnqualifiedName(UnqualifiedNameAST *node)
 
     if(!had) //only forward-declarations, register to any.
       if(m_visitor)
-        m_visitor->newUse( node, node->id, node->id+1, m_find.lastDeclarations()[0] );
+        m_visitor->newUse( node, start_token,end_token, m_find.lastDeclarations()[0] );
   } else {
     if(node == m_finalName) {
       if(m_visitor) { //Create a zero use, which will be highlighted as an error
@@ -174,10 +179,11 @@ ExpressionEvaluationResult NameASTVisitor::processTemplateArgument(TemplateArgum
     if(!m_visitor) {
       m_visitor = new ExpressionVisitor(m_session, m_source);
       ownVisitor = true;
+    }
+    if (!node->expression->ducontext) {
       node->expression->ducontext = const_cast<DUContext*>(m_localContext);
     }
-    
-    m_visitor->visit( node->expression );
+    m_visitor->parse( node->expression );
 
     if( m_visitor->lastType() ) {
       LOCKDUCHAIN;
