@@ -45,7 +45,7 @@
 #include <kio/netaccess.h>
 #include <ktexteditor/document.h>
 #include <ktexteditor/view.h>
-#include <ktexteditor/smartinterface.h>
+#include <KDesktopFile>
 #include <language/codecompletion/codecompletion.h>
 
 #include <interfaces/icore.h>
@@ -66,7 +66,6 @@
 #include <language/duchain/stringhelpers.h>
 #include <language/duchain/duchainlock.h>
 #include <language/duchain/topducontext.h>
-#include <language/duchain/smartconverter.h>
 #include <language/duchain/functiondefinition.h>
 #include <language/codegen/coderepresentation.h>
 #include <interfaces/contextmenuextension.h>
@@ -85,6 +84,7 @@
 #include "cppduchain/cppduchain.h"
 #include "codegen/codeassistant.h"
 #include "codegen/cppnewclass.h"
+#include <interfaces/foregroundlock.h>
 //#include "codegen/makeimplementationprivate.h"
 
 #include "includepathresolver.h"
@@ -94,6 +94,7 @@
 #include "codegen/simplerefactoring.h"
 #include "includepathcomputer.h"
 #include "codecompletion/missingincludemodel.h"
+
 //#include <valgrind/callgrind.h>
 
 
@@ -151,10 +152,20 @@ public:
 };
 #endif
 
+
+static QStringList mimeTypesList()
+{
+    KDesktopFile desktopFile("services", QString("kdevcppsupport.desktop"));
+    const KConfigGroup& desktopGroup = desktopFile.desktopGroup();
+    QString mimeTypesStr = desktopGroup.readEntry("X-KDevelop-SupportedMimeTypes", "");
+    return mimeTypesStr.split(QChar(','), QString::SkipEmptyParts);
+}
+
 CppLanguageSupport::CppLanguageSupport( QObject* parent, const QVariantList& /*args*/ )
     : KDevelop::IPlugin( KDevCppSupportFactory::componentData(), parent ),
       KDevelop::ILanguageSupport(),
-      m_standardMacros(0)
+      m_standardMacros(0),
+      m_mimeTypes(mimeTypesList())
 {
     m_self = this;
 
@@ -182,17 +193,20 @@ CppLanguageSupport::CppLanguageSupport( QObject* parent, const QVariantList& /*a
 
     if( quickOpen )
         quickOpen->registerProvider( IncludeFileDataProvider::scopes(), QStringList(i18n("Files")), m_quickOpenDataProvider );
-    else
-        kWarning() << "Quickopen not found";
+    // else we are in NoUi mode (duchainify, unit tests, ...) and hence cannot find the Quickopen plugin
 
 #ifdef DEBUG_UI_LOCKUP
     m_blockTester = new UIBlockTester(LOCKUP_INTERVAL);
 #endif
 
     m_assistant = new Cpp::StaticCodeAssistant;
+
+    foreach(QString mimeType, m_mimeTypes){
+        KDevelop::IBuddyDocumentFinder::addFinder(mimeType,this);
+    }
 }
 
-void CppLanguageSupport::createActionsForMainWindow (Sublime::MainWindow* window, QString& _xmlFile, KActionCollection& actions)
+void CppLanguageSupport::createActionsForMainWindow (Sublime::MainWindow* /*window*/, QString& _xmlFile, KActionCollection& actions)
 {
     _xmlFile = xmlFile();
 
@@ -272,7 +286,7 @@ void CppLanguageSupport::switchDefinitionDeclaration()
   if(standardCtx) {
     Declaration* definition = 0;
 
-    DUContext* ctx = standardCtx->findContext(cursor);
+    DUContext* ctx = standardCtx->findContext(standardCtx->transformToLocalRevision(cursor));
     if(!ctx)
       ctx = standardCtx;
 
@@ -308,7 +322,7 @@ void CppLanguageSupport::switchDefinitionDeclaration()
     FunctionDefinition* def = dynamic_cast<FunctionDefinition*>(definition);
     if(def && def->declaration()) {
       Declaration* declaration = def->declaration();
-      KTextEditor::Range targetRange = declaration->range().textRange();
+      KTextEditor::Range targetRange = declaration->rangeInCurrentRevision().textRange();
       KUrl url(declaration->url().str());
       kDebug() << "found definition that has declaration: " << definition->toString() << "range" << targetRange << "url" << url;
       lock.unlock();
@@ -338,10 +352,10 @@ void CppLanguageSupport::switchDefinitionDeclaration()
 
   if(def) {
     KUrl url(def->url().str());
-    KTextEditor::Range targetRange = def->range().textRange();
+    KTextEditor::Range targetRange = def->rangeInCurrentRevision().textRange();
 
     if(def->internalContext()) {
-      targetRange.end() = def->internalContext()->range().end.textCursor();
+      targetRange.end() = def->internalContext()->rangeInCurrentRevision().end.textCursor();
     }else{
       kDebug(9007) << "Declaration does not have internal context";
     }
@@ -376,6 +390,7 @@ CppLanguageSupport::~CppLanguageSupport()
 {
     ILanguage* lang = language();
     if (lang) {
+        TemporarilyReleaseForegroundLock release;
         lang->parseLock()->lockForWrite();
         m_self = 0; //By locking the parse-mutexes, we make sure that parse- and preprocess-jobs get a chance to finish in a good state
         lang->parseLock()->unlock();
@@ -392,6 +407,10 @@ CppLanguageSupport::~CppLanguageSupport()
     delete m_blockTester;
 #endif
     delete m_assistant;
+
+    foreach(QString mimeType, m_mimeTypes){
+        KDevelop::IBuddyDocumentFinder::removeFinder(mimeType);
+    }
 }
 
 CppLanguageSupport* CppLanguageSupport::self() {
@@ -403,7 +422,7 @@ KDevelop::ParseJob *CppLanguageSupport::createParseJob( const KUrl &url )
     return new CPPParseJob( url );
 }
 
-const KDevelop::ICodeHighlighting *CppLanguageSupport::codeHighlighting() const
+KDevelop::ICodeHighlighting *CppLanguageSupport::codeHighlighting() const
 {
     return m_highlights;
 }
@@ -430,7 +449,7 @@ TopDUContext* CppLanguageSupport::standardContext(const KUrl& url, bool proxyCon
   DUChainReadLocker lock(DUChain::lock());
   const ParsingEnvironment* env = PreprocessJob::standardEnvironment();
   KDevelop::TopDUContext* top;
-  top = KDevelop::DUChain::self()->chainForDocument(url, env, Cpp::EnvironmentManager::self()->isSimplifiedMatching());
+  top = KDevelop::DUChain::self()->chainForDocument(url, env, Cpp::EnvironmentManager::self()->isSimplifiedMatching() || proxyContext);
 
   if( !top ) {
     //kDebug(9007) << "Could not find perfectly matching version of " << url << " for completion";
@@ -445,23 +464,65 @@ TopDUContext* CppLanguageSupport::standardContext(const KUrl& url, bool proxyCon
 
   if(top && (top->parsingEnvironmentFile() && top->parsingEnvironmentFile()->isProxyContext()) && !proxyContext)
   {
-    if(!top->importedParentContexts().isEmpty())
+    top = DUChainUtils::contentContextFromProxyContext(top);
+    if(!top)
     {
-      top = dynamic_cast<TopDUContext*>(top->importedParentContexts().first().context(0));
-
-      if(!top)
-      {
-        kDebug(9007) << "WARNING: Proxy-context had invalid content-context";
-      }
-
-    } else {
-      kDebug(9007) << "ERROR: Proxy-context has no content-context";
+      kDebug(9007) << "WARNING: Proxy-context had invalid content-context";
     }
   }
 
   return top;
 }
 
+
+
+// Returns the base path (without extension) and the first character of the
+// file extension in lowercase (or '?' if there is no extension)
+// for path="Folder/File.CPP", returns ("Folder/File", 'c').
+// for path="folder/file", returns ("folder/file", '?')
+QPair<QString, QChar> CppLanguageSupport::basePathAndType(const QString& path)
+{
+    int idxSlash = path.lastIndexOf("/");
+    int idxDot = path.lastIndexOf(".");
+    QString basepath;
+    QChar filetype('?');
+    if(idxSlash >= 0 && idxDot >= 0 && idxDot > idxSlash)
+    {
+        basepath = path.left(idxDot);
+        //QString ext = path.right(path.length() - idxDot);
+        if(idxDot + 1 < path.length())
+            filetype = path[idxDot + 1].toLower();
+    }
+    else
+    {
+        basepath = path;
+    }
+    kDebug() << qMakePair(basepath, filetype);
+    return qMakePair(basepath, filetype);
+}
+
+
+// Bahavior: Considers the URLs as buddy documents if the base path (=without extension)
+// is the same, and one extension starts with h/H and the other one with c/C.
+// For example, foo.hpp and foo.C are buddies.
+bool CppLanguageSupport::areBuddies(const KUrl& url1, const KUrl& url2)
+{
+    QPair<QString, QChar> split1 = basePathAndType(url1.toLocalFile());
+    QPair<QString, QChar> split2 = basePathAndType(url2.toLocalFile());
+    return(split1.first == split2.first && ((split1.second == 'h' && split2.second == 'c') ||
+                                            (split1.second == 'c' && split2.second == 'h')));
+}
+
+// Behavior: places foo.h* / foo.H* left of foo.c* / foo.C*
+bool CppLanguageSupport::buddyOrder(const KUrl& url1, const KUrl& url2)
+{
+    QPair<QString, QChar> split1 = basePathAndType(url1.toLocalFile());
+    QPair<QString, QChar> split2 = basePathAndType(url2.toLocalFile());
+    // Precondition is that the two URLs are buddies, so don't check it
+    return(split1.second == 'h' && split2.second == 'c');
+}
+
+
 QPair<QPair<QString, SimpleRange>, QString> CppLanguageSupport::cursorIdentifier(const KUrl& url, const SimpleCursor& position) const {
   KDevelop::IDocument* doc = core()->documentController()->documentForUrl(url);
   if(!doc || !doc->textDocument() || !doc->textDocument()->activeView())
@@ -547,7 +608,7 @@ QPair<TopDUContextPointer, SimpleRange> CppLanguageSupport::importedContextForPo
     //It's an #include, find out which file was included at the given line
     foreach(const DUContext::Import &imported, ctx->importedParentContexts()) {
       if(imported.context(0)) {
-        if(ctx->importPosition(imported.context(0)).line == wordRange.start.line) {
+        if(ctx->transformFromLocalRevision(ctx->importPosition(imported.context(0))).line == wordRange.start.line) {
           if(TopDUContext* importedTop = dynamic_cast<TopDUContext*>(imported.context(0)))
             return qMakePair(TopDUContextPointer(importedTop), wordRange);
         }
