@@ -51,19 +51,15 @@ public:
   //Symbol associated to the token. This only works if this is a simple symbol
   //only consisting of one identifier(not comments), does not work for operators like "->" or numbers like "50"
   KDevelop::IndexedString symbol() const;
-  
+  //The index of the symbol associated to the token.
+  //The notes from @c symbol() apply as well.
+  uint symbolIndex() const;
+
   //This always works, but is expensive
   QString symbolString() const;
   QByteArray symbolByteArray() const;
 
   uint symbolLength() const;
-  
-  ///@todo adymo: find out what @p right_brace is
-  union
-  {
-    //const NameSymbol *symbol;
-    uint right_brace;
-  } extra;
 };
 
 /**Stream of tokens found by lexer.
@@ -72,29 +68,29 @@ All tokens are destructed when this stream is deleted.
 
 The stream has a "cursor" which is simply an integer which defines
 the offset (index) of the token currently "observed" from the beginning of
-the stream.*/
-class TokenStream
+the stream.
+
+TODO: reuse some pool / container class for the token array
+NOTE: token_count is actually the *size* of the token pool
+      the last actually used token is lastToken
+*/
+class TokenStream : public QVector<Token>
 {
 private:
   TokenStream(const TokenStream &);
   void operator = (const TokenStream &);
 
 public:
-  /**Creates a token stream with the default size of 1024 tokens.*/
+  /**Creates a token stream with the default reserved size of 1024 tokens.*/
   inline TokenStream(uint size = 1024)
-     : tokens(0),
-       index(0),
-       token_count(0)
+    : index(0)
   {
-    resize(size);
+    reserve(size);
   }
 
-  inline ~TokenStream()
-  { ::free(tokens); }
-
-  /**@return the size of the token stream.*/
-  inline uint size() const
-  { return token_count; }
+  /**@return the token at position @p index.*/
+  inline const Token &token(int index) const
+  { return at(index); }
 
   /**@return the "cursor" - the offset (index) of the token
   currently "observed" from the beginning of the stream.*/
@@ -105,14 +101,6 @@ public:
   inline void rewind(int i)
   { index = i; }
 
-  /**Resizes the token stream.*/
-  void resize(uint size)
-  {
-    Q_ASSERT(size > 0);
-    tokens = (Token*) ::realloc(tokens, sizeof(Token) * size);
-    token_count = size;
-  }
-
   /**Updates the cursor position to point to the next token and returns
   the cursor.*/
   inline uint nextToken()
@@ -120,42 +108,26 @@ public:
 
   /**@return the kind of the next (LA) token in the stream.*/
   inline int lookAhead(uint i = 0) const
-  { return tokens[index + i].kind; }
+  { return at(index + i).kind; }
 
   /**@return the kind of the current token in the stream.*/
   inline int kind(uint i) const
-  { return tokens[i].kind; }
+  { return at(i).kind; }
 
   /**@return the position of the current token in the c++ source buffer.*/
   inline uint position(uint i) const
-  { return tokens[i].position; }
+  { return at(i).position; }
 
-  /**@return the name symbol of the current token.*/
-  //inline const NameSymbol *symbol(uint i) const
-  //{ return tokens[i].extra.symbol; }
-
-  /**@return the position of the matching right brace in the
-  c++ source buffer.
-  @todo this doesn't seem to work as the lexer does not provide this
-  information at the moment.*/
-  inline uint matchingBrace(uint i) const
-  { return tokens[i].extra.right_brace; }
-
-  /**@return the token at position @p index.*/
-  inline Token &operator[](int index)
-  { Q_ASSERT(index >= 0 && index < (int)token_count); return tokens[index]; }
-
-  /**@return the token at position @p index.*/
-  inline const Token &token(int index) const
-  { return tokens[index]; }
+  /**
+   * Split the right shift token at @p index into two distinct right angle brackets.
+   * 
+   * Required to support 14.2/3 of the spec, see also:
+   * http://www.open-std.org/jtc1/sc22/wg21/docs/papers/2005/n1757.html
+   */
+  void splitRightShift(uint index);
 
 private:
-  Token *tokens;
   uint index;
-  uint token_count;
-
-private:
-  friend class Lexer;
 };
 
 /**C++ Lexer.*/
@@ -187,6 +159,8 @@ private:
   void scan_int_constant();
   void scan_char_constant();
   void scan_string_constant();
+  void scan_raw_string_constant();
+  void scan_raw_string_or_identifier();
   void scan_invalid_input();
   void scan_preprocessor();
 
@@ -287,7 +261,10 @@ private:
       ret.current += offset;
       return ret;
     }
-    
+
+    // useful for debugging
+    QString toString() const;
+
     uint* current;
   };
   
