@@ -24,6 +24,7 @@
 
 #include <QtCore/QStringList>
 #include <QtCore/QProcess>
+#include <QtCore/QFileInfo>
 
 #include <KDebug>
 #include <kshell.h>
@@ -81,10 +82,16 @@ MakeJob::~MakeJob()
 void MakeJob::start()
 {
     kDebug(9037) << "Building with make" << m_command << m_overrideTarget;
+    if (!m_item)
+    {
+        setError(ItemNoLongerValidError);
+        setErrorText(i18n("Build item no longer available"));
+        return emitResult();
+    }
 
     if( m_item->type() == KDevelop::ProjectBaseItem::File ) {
         setError(IncorrectItemError);
-        setErrorText("Internal error: cannot build a file item");
+        setErrorText(i18n("Internal error: cannot build a file item"));
         return emitResult();
     }
 
@@ -94,6 +101,16 @@ void MakeJob::start()
         setErrorText(i18n("Invalid build directory '%1'", buildDir.prettyUrl()));
         return emitResult();
     }
+    else if( !buildDir.isLocalFile() ) {
+        setError(InvalidBuildDirectoryError);
+        setErrorText(i18n("'%1' is not a local path", buildDir.prettyUrl()));
+        return emitResult();
+    }
+    else if ( !QFileInfo(buildDir.toLocalFile()).isDir() ) {
+        setError(InvalidBuildDirectoryError);
+        setErrorText(i18n("'%1' is not a directory", buildDir.prettyUrl()));
+        return emitResult();
+    }
 
     QStringList cmd = computeBuildCommand();
     if( cmd.isEmpty() ) {
@@ -118,12 +135,12 @@ void MakeJob::start()
     m_process = new KProcess(this);
     m_process->setOutputChannelMode( KProcess::MergedChannels );
     m_lineMaker = new ProcessLineMaker( m_process );
-    connect( m_lineMaker, SIGNAL(receivedStdoutLines( const QStringList& ) ),
-             this, SLOT( addStandardOutput( const QStringList& ) ) );
-    connect( m_process, SIGNAL( error( QProcess::ProcessError ) ),
-             this, SLOT( procError( QProcess::ProcessError ) ) );
-    connect( m_process, SIGNAL( finished( int, QProcess::ExitStatus ) ),
-             this, SLOT( procFinished( int, QProcess::ExitStatus ) ) );
+    connect( m_lineMaker, SIGNAL(receivedStdoutLines(QStringList)),
+             this, SLOT(addStandardOutput(QStringList)) );
+    connect( m_process, SIGNAL(error(QProcess::ProcessError)),
+             this, SLOT(procError(QProcess::ProcessError)) );
+    connect( m_process, SIGNAL(finished(int,QProcess::ExitStatus)),
+             this, SLOT(procFinished(int,QProcess::ExitStatus)) );
 
     m_process->setEnvironment( environmentVars() );
     m_process->setWorkingDirectory( buildDir.toLocalFile() );
@@ -183,7 +200,11 @@ QStringList MakeJob::computeBuildCommand() const
     KSharedConfig::Ptr configPtr = m_item->project()->projectConfiguration();
     KConfigGroup builderGroup( configPtr, "MakeBuilder" );
 
+#ifdef _MSC_VER
+    QString makeBin = builderGroup.readEntry("Make Binary", "nmake");
+#else
     QString makeBin = builderGroup.readEntry("Make Binary", "make");
+#endif
     cmdline << makeBin;
 
     if( ! builderGroup.readEntry("Abort on First Error", true) )
@@ -244,7 +265,7 @@ QStringList MakeJob::computeBuildCommand() const
           arguments << cmdline;
         } else { //default
           suCommandName = "kdesu";   
-          arguments << "-t" << "-c" << cmdline;
+          arguments << "-t" << "--" << cmdline;
         }
         kdesuline << suCommandName << arguments;
         cmdline = kdesuline;
