@@ -16,9 +16,9 @@
 // @todo could get these from emacs compile.el
 QList<ErrorFormat> ErrorFormat::errorFormats = QList<ErrorFormat>()
     // GCC - another case, eg. for #include "pixmap.xpm" which does not exists
-    << ErrorFormat( "([^: \t]+):([0-9]+):([0-9]+):([^0-9]+)", 1, 2, 4, 3 )
+    << ErrorFormat( "([^:\t]+):([0-9]+):([0-9]+):([^0-9]+)", 1, 2, 4, 3 )
     // GCC
-    << ErrorFormat( "([^: \t]+):([0-9]+):([^0-9]+)", 1, 2, 3 )
+    << ErrorFormat( "([^:\t]+):([0-9]+):([^0-9]+)", 1, 2, 3 )
     // ICC
     << ErrorFormat( "([^: \\t]+)\\(([0-9]+)\\):([^0-9]+)", 1, 2, 3, "intel" )
     //libtool link
@@ -62,7 +62,7 @@ QList<ActionFormat> ActionFormat::actionFormats = QList<ActionFormat>()
                      "linking"), 1, 2, "^linking (.*)" )
     //cmake
     << ActionFormat( i18n("built"), -1, 1, "\\[.+%\\] Built target (.*)" )
-    << ActionFormat( i18n("compiling"), -1, 1, "\\[.+%\\] Building .* object (.*)" )
+    << ActionFormat( i18n("compiling"), "cmake", "\\[.+%\\] Building .* object (.*)/CMakeFiles/", 1 )
     << ActionFormat( i18n("generating"), -1, 1, "\\[.+%\\] Generating (.*)" )
     << ActionFormat( i18nc("Linking object files into a library or executable",
                      "linking"), -1, 1, "^Linking (.*)" )
