@@ -48,6 +48,7 @@ static QString currentBuildDirKey = "CurrentBuildDir";
 static QString currentCMakeBinaryKey = "Current CMake Binary";
 static QString currentBuildTypeKey = "CurrentBuildType";
 static QString currentInstallDirKey = "CurrentInstallDir";
+static QString currentEnvironmentKey = "CurrentEnvironment";
 static QString currentExtraArgumentsKey = "Extra Arguments";
 static QString projectRootRelativeKey = "ProjectRootRelative";
 static QString projectBuildDirs = "BuildDirs";
@@ -55,6 +56,7 @@ static QString projectBuildDirs = "BuildDirs";
 namespace CMake
 {
 
+///NOTE: when you change this, update @c defaultConfigure in cmakemanagertest.cpp
 bool checkForNeedingConfigure( KDevelop::ProjectBaseItem* item )
 {
     KConfigGroup cmakeGrp = item->project()->projectConfiguration()->group("CMake");
@@ -196,6 +198,12 @@ void setCurrentExtraArguments( KDevelop::IProject* project, const QString& strin
     cmakeGrp.sync();
 }
 
+QString currentEnvironment(KDevelop::IProject* project)
+{
+    KConfigGroup cmakeGrp = project->projectConfiguration()->group("CMake");
+    return cmakeGrp.readEntry(currentEnvironmentKey, QString());
+}
+
 ICMakeDocumentation* cmakeDocumentation()
 {
     ICMakeDocumentation* p=KDevelop::ICore::self()->pluginController()->extensionForPlugin<ICMakeDocumentation>("org.kdevelop.ICMakeDocumentation");
