@@ -54,7 +54,8 @@ namespace CMakeParserUtils
     /** Runs the process specified by @p execName with @p args */
     KDEVCMAKECOMMON_EXPORT QString executeProcess(const QString& execName, const QStringList& args=QStringList());
     
-    KDEVCMAKECOMMON_EXPORT KDevelop::ReferencedTopDUContext includeScript( const QString& file, KDevelop::ReferencedTopDUContext parent, CMakeProjectData* data, const QString& sourcedir);
+    KDEVCMAKECOMMON_EXPORT KDevelop::ReferencedTopDUContext includeScript( const QString& file, KDevelop::ReferencedTopDUContext parent, CMakeProjectData* data,
+                                                                           const QString& sourcedir, const QMap< QString, QString >& env);
 }
 
 #endif
